@@ -9,14 +9,14 @@
 
 class MockBridge;
 
-class MockDecoration : public KDecoration2::Decoration
+class MockDecoration : public KDecoration3::Decoration
 {
     Q_OBJECT
 public:
     explicit MockDecoration(QObject *parent, const QVariantList &args);
     explicit MockDecoration(MockBridge *bridge);
     bool init() override;
-    void paint(QPainter *painter, const QRect &repaintRegion) override;
+    void paint(QPainter *painter, const QRectF &repaintRegion) override;
     void setOpaque(bool set);
     using Decoration::setBorders;
     void setBorders(const QMargins &m);
